@@ -122,12 +122,15 @@ def pytest_generate_tests(metafunc):
     # 获取当前用例对应的测试数据路径
     data_path = find_data_path_by_case(belong_app, module_name)
     if not data_path:
-        logger.error(f"测试数据文件: {func_file_path} 不存在")
-        traceback.print_exc()
-        pytest.exit(ExitCode.CASE_YAML_NOT_EXIST)
+        logger.warning(f"测试数据文件: {func_file_path} 不存在")
+        return
+        # traceback.print_exc()
+        # pytest.exit(ExitCode.CASE_YAML_NOT_EXIST)
     # yml转json
     test_data = CachedYamlLoader(data_path).load_yml()
-
+    if not test_data:
+        logger.warning(f"测试数据文件: {func_file_path} 内容为空")
+        return
     # 测试用例公共数据
     case_common = test_data.get("case_common")
     # 忽略的用例直接跳过
@@ -167,6 +170,8 @@ def pytest_generate_tests(metafunc):
     case_data["_belong_app"] = belong_app
     # 根据belong_app获取域名
     domain = CONTEXT.get(key="domain", app=belong_app)
+    if not domain:
+        return
     domain = domain if domain.startswith("http") else f"https://{domain}"
     # 获取request中的url
     url = case_data.get("request").get("url")
@@ -289,19 +294,18 @@ def pytest_collection_modifyitems(items):
         data = item.callspec.params["data"]
         if isinstance(data, dict):
             marks = data.get("_marks")
-            for mark in marks:
-                item.add_marker(mark)
-
-
+            if marks:
+                for mark in marks:
+                    item.add_marker(mark)
 
 
 def pytest_collection_finish(session):
     """获取最终排序后的 items 列表"""
-    logger.info(f"共收集到 {len(session.items)} 个测试用例")
     if not session.items:
         pytest.exit("未收集到用例")
     # 过滤掉item名称是test_setup或test_teardown的
     session.items = [item for item in session.items if item.name not in ["test_setup", "test_teardown"]]
+    logger.info(f"共收集到 {len(session.items)} 个测试用例")
 
     # 1. 筛选出带井号 名称带'#' 的item，并记录原始索引
     hash_items_with_index = [(index, item) for index, item in enumerate(session.items) if "#" in item.name]
@@ -322,8 +326,10 @@ def pytest_collection_finish(session):
         grouped_data = OrderedDict()
         # 按照#号后面的数字进行排序并分组
         for item in group_values:
-            index = re.search(pattern, item.name).group(1)
-            grouped_data.setdefault(index, []).append(item)
+            match_result = re.search(pattern, item.name)
+            if match_result:
+                index = match_result.group(1)
+                grouped_data.setdefault(index, []).append(item)
         # 标记每个分组的第一个和最后一个
         for group2 in grouped_data.values():
             group2[0].funcargs["first"] = True
@@ -356,9 +362,9 @@ def pytest_runtestloop(session):
             cls = getattr(importlib.import_module(module_path), class_name)
             cls().run()
         except Exception as e:
-            logger.error(str(e))
-            traceback.print_exc()
-            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
+            logger.warning(str(e))
+            # traceback.print_exc()
+            # pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
 
 
 def pytest_sessionfinish(session, exitstatus):
@@ -529,6 +535,7 @@ def pytest_terminal_summary(terminalreporter, exitstatus, config):
     if settings.ONLY_LINUX_NOTIFICATION:
         if "linux" not in platform.platform().lower():
             return
+    # 发送测试结果群消息
     for webhook in settings.LARK_WEBHOOKS.get(CONTEXT.get("env")):
         LarkUtil(webhook).send_test_report(
             total=total,
@@ -539,6 +546,16 @@ def pytest_terminal_summary(terminalreporter, exitstatus, config):
             job_name=os.environ.get("JOB_NAME"),
             env=CONTEXT.get("env")
         )
+    # 发送测试结果统计
+    LarkUtil(settings.LARK_CHART_WEBHOOKS.get(CONTEXT.get("env"))).send_test_chart(
+        total=total,
+        passed=passed,
+        failed=failed,
+        skipped=skipped,
+        job_name=os.environ.get("JOB_NAME"),
+        env=CONTEXT.get("env")
+    )
+
 
 def pytest_exception_interact(node, call, report):
     """
@@ -583,10 +600,14 @@ def inner_login(app):
     login_cls = getattr(module, f"{snake_to_pascal(app)}Login")
     setattr(Http, app, login_cls(app))
     # Token 过期时间写入上下文
-    token_expiry = CONTEXT.get(app).get("token_expiry")
-    if token_expiry:
-        expire_time = datetime.now() + timedelta(seconds=token_expiry)
-        _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
+    application = CONTEXT.get(app)
+    if application:
+        token_expiry = application.get("token_expiry")
+        if token_expiry:
+            expire_time = datetime.now() + timedelta(seconds=token_expiry)
+            _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
+    else:
+        logger.warning(f'{app} not found')
 
 
 def login():
